==> core-1.23.0-sources.jar: software/amazon/awscdk/core/IFragmentConcatenator.java <==
package software.amazon.awscdk.core;

/**
 * Function used to concatenate symbols in the target document language.
 * <p>
 * Interface so it could potentially be exposed over jsii.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.21.2 (build 4370756)", date = "2020-02-07T03:00:47.236Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.IFragmentConcatenator")
@software.amazon.jsii.Jsii.Proxy(IFragmentConcatenator.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IFragmentConcatenator extends software.amazon.jsii.JsiiSerializable {

    /**
     * Join the fragment on the left and on the right.
     * <p>
     * EXPERIMENTAL
     * <p>
     * @param left This parameter is required.
     * @param right This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Object join(final java.lang.Object left, final java.lang.Object right);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.IFragmentConcatenator {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Join the fragment on the left and on the right.
         * <p>
         * EXPERIMENTAL
         * <p>
         * @param left This parameter is required.
         * @param right This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public java.lang.Object join(final java.lang.Object left, final java.lang.Object right) {
            return this.jsiiCall("join", java.lang.Object.class, new Object[] { left, right });
        }
    }
}

==> core-1.24.0-sources.jar: software/amazon/awscdk/core/IFragmentConcatenator.java <==
package software.amazon.awscdk.core;

/**
 * Function used to concatenate symbols in the target document language.
 * <p>
 * Interface so it could potentially be exposed over jsii.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-02-13T18:53:48.649Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.IFragmentConcatenator")
@software.amazon.jsii.Jsii.Proxy(IFragmentConcatenator.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IFragmentConcatenator extends software.amazon.jsii.JsiiSerializable {

    /**
     * Join the fragment on the left and on the right.
     * <p>
     * EXPERIMENTAL
     * <p>
     * @param left This parameter is required.
     * @param right This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Object join(final @org.jetbrains.annotations.NotNull java.lang.Object left, final @org.jetbrains.annotations.NotNull java.lang.Object right);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.IFragmentConcatenator {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Join the fragment on the left and on the right.
         * <p>
         * EXPERIMENTAL
         * <p>
         * @param left This parameter is required.
         * @param right This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public @org.jetbrains.annotations.NotNull java.lang.Object join(final @org.jetbrains.annotations.NotNull java.lang.Object left, final @org.jetbrains.annotations.NotNull java.lang.Object right) {
            return this.jsiiCall("join", java.lang.Object.class, new Object[] { left, right });
        }
    }
}
